@@ -8,11 +8,13 @@ public class CliOptions {
 	public String password;
 	public String command;
 	public String[] commandArguments;
+	public boolean debug;
 
 	@Override
 	public String toString(){
 		return "user: " + user
 				+ ", password: " + password
+				+ ", debug: " + debug
 				+ ", url: " + (url == null ? "null" : url.toString()
 				+ ", command: " + command);
 	}
